@@ -3,7 +3,8 @@ import os
 import re
 import shutil
 import typing
-import warnings
+
+import pandas as pd
 
 import audbackend
 import audeer
@@ -16,12 +17,10 @@ from audb.core.api import (
     dependencies,
     latest_version,
 )
+from audb.core.backward import parse_deprecated_load_arguments
 from audb.core.dependencies import Dependencies
 from audb.core.flavor import Flavor
-from audb.core.utils import (
-    lookup_backend,
-    mix_mapping,
-)
+from audb.core.utils import lookup_backend
 
 
 def _cached_versions(
@@ -65,7 +64,7 @@ def _cached_files(
         cached_versions: typing.Sequence[
             typing.Tuple[LooseVersion, str, Dependencies],
         ],
-        flavor: Flavor,
+        flavor: typing.Optional[Flavor],
         verbose: bool,
 ) -> (typing.Sequence[typing.Union[str, str]], typing.Sequence[str]):
     r"""Find cached files."""
@@ -82,18 +81,19 @@ def _cached_files(
         file_version = LooseVersion(deps.version(file))
         for cache_version, cache_root, cache_deps in cached_versions:
             if cache_version >= file_version:
-                if deps.checksum(file) == cache_deps.checksum(file):
-                    path = os.path.join(cache_root, file)
-                    if flavor.format is not None:
-                        path = audeer.replace_file_extension(
-                            path,
-                            flavor.format,
-                        )
-                    if os.path.exists(path):
-                        found = True
-                        break
+                if file in cache_deps:
+                    if deps.checksum(file) == cache_deps.checksum(file):
+                        path = os.path.join(cache_root, file)
+                        if flavor and flavor.format is not None:
+                            path = audeer.replace_file_extension(
+                                path,
+                                flavor.format,
+                            )
+                        if os.path.exists(path):
+                            found = True
+                            break
         if found:
-            if flavor.format is not None:
+            if flavor and flavor.format is not None:
                 file = audeer.replace_file_extension(
                     file,
                     flavor.format,
@@ -159,58 +159,6 @@ def _database_is_complete(
     return complete
 
 
-def _database_header(
-        db_root: str,
-        db_root_tmp: str,
-        name: str,
-        version: str,
-        flavor: Flavor,
-        backend: audbackend.Backend,
-) -> audformat.Database:
-    local_header = os.path.join(db_root, define.HEADER_FILE)
-    if not os.path.exists(local_header):
-        local_header = os.path.join(db_root_tmp, define.HEADER_FILE)
-        remote_header = backend.join(name, define.HEADER_FILE)
-        backend.get_file(remote_header, local_header, version)
-        db = audformat.Database.load(db_root_tmp, load_data=False)
-        db.meta['audb'] = {
-            'root': db_root,
-            'version': version,
-            'flavor': flavor.arguments,
-            'complete': False,
-        }
-        db.save(db_root_tmp, header_only=True)
-        _move_file(db_root_tmp, db_root, define.HEADER_FILE)
-    return audformat.Database.load(db_root, load_data=False)
-
-
-def _database_root(
-        name: str,
-        version: str,
-        flavor: Flavor,
-        cache_root: typing.Optional[str],
-) -> (str, str):
-    cache_roots = [
-        default_cache_root(True),  # check shared cache first
-        default_cache_root(False),
-    ] if cache_root is None else [cache_root]
-    for cache_root in cache_roots:
-        db_root = audeer.safe_path(
-            os.path.join(
-                cache_root,
-                flavor.path(name, version),
-            )
-        )
-        if os.path.exists(db_root):
-            break
-
-    db_root_tmp = db_root + '~'
-    audeer.mkdir(db_root)
-    audeer.mkdir(db_root_tmp)
-
-    return db_root, db_root_tmp
-
-
 def _fix_media_ext(
         tables: typing.Sequence[audformat.Table],
         format: str,
@@ -257,7 +205,7 @@ def _full_path(
 
 
 def _get_media_from_backend(
-        db: audformat.Database,
+        name: str,
         media: typing.Sequence[str],
         db_root: str,
         db_root_tmp: str,
@@ -296,7 +244,7 @@ def _get_media_from_backend(
 
     def job(archive: str, version: str):
         archive = backend.join(
-            db.name,
+            name,
             define.DEPEND_TYPE_NAMES[define.DependType.MEDIA],
             archive,
         )
@@ -421,7 +369,6 @@ def _get_tables_from_cache(
         cached_versions: typing.Sequence[
             typing.Tuple[LooseVersion, str, Dependencies]
         ],
-        flavor: Flavor,
         num_workers: int,
         verbose: bool,
 ) -> typing.Sequence[str]:
@@ -431,7 +378,7 @@ def _get_tables_from_cache(
         tables,
         deps,
         cached_versions,
-        flavor,
+        None,
         verbose,
     )
 
@@ -454,32 +401,131 @@ def _get_tables_from_cache(
     return missing_tables
 
 
-def _include_exclude_mapping(
+def _load_media(
+        media: typing.Sequence[str],
+        backend: audbackend.Backend,
+        db_root: str,
+        db_root_tmp: str,
+        name: str,
+        version: str,
+        cached_versions: typing.Optional[
+            typing.Sequence[typing.Tuple[LooseVersion, str, Dependencies]]
+        ],
         deps: Dependencies,
-        include: typing.Optional[typing.Union[str, typing.Sequence[str]]],
-        exclude: typing.Optional[typing.Union[str, typing.Sequence[str]]],
-) -> typing.Sequence[str]:
+        flavor: Flavor,
+        cache_root: str,
+        num_workers: int,
+        verbose: bool,
+):
+    r"""Load media files to cache.
 
-    media = None
+    All media files not existing in cache yet
+    are copied from the corresponding flavor cache
+    folder of other versions of the database
+    or are downloaded from the backend.
 
-    if include is not None:
-        archives = set([deps.archive(f) for f in deps.media])
-        if isinstance(include, str):
-            pattern = re.compile(include)
-            include = [a for a in archives if pattern.search(a)]
-        media = [x for x in deps.media if deps.archive(x) in include]
+    """
+    missing_media = _missing_media(
+        db_root,
+        media,
+        flavor,
+        verbose,
+    )
+    if missing_media:
+        if cached_versions is None:
+            cached_versions = _cached_versions(
+                name,
+                version,
+                flavor,
+                cache_root,
+            )
+        if cached_versions:
+            missing_media = _get_media_from_cache(
+                missing_media,
+                db_root,
+                db_root_tmp,
+                deps,
+                cached_versions,
+                flavor,
+                num_workers,
+                verbose,
+            )
+        if missing_media:
+            if backend is None:
+                backend = lookup_backend(name, version)
+            _get_media_from_backend(
+                name,
+                missing_media,
+                db_root,
+                db_root_tmp,
+                flavor,
+                deps,
+                backend,
+                num_workers,
+                verbose,
+            )
 
-    if media is None:
-        media = deps.media
 
-    if exclude is not None:
-        archives = set([deps.archive(f) for f in deps.media])
-        if isinstance(exclude, str):
-            pattern = re.compile(exclude)
-            exclude = [a for a in archives if pattern.search(a)]
-        media = [x for x in media if deps.archive(x) not in exclude]
+def _load_tables(
+        tables: typing.Sequence[str],
+        backend: audbackend.Backend,
+        db_root: str,
+        db_root_tmp: str,
+        db: audformat.Database,
+        version: str,
+        cached_versions: typing.Optional[
+            typing.Sequence[typing.Tuple[LooseVersion, str, Dependencies]]
+        ],
+        deps: Dependencies,
+        flavor: Flavor,
+        cache_root: str,
+        num_workers: int,
+        verbose: bool,
+):
+    r"""Load table files to cache.
 
-    return media
+    All table files not existing in cache yet
+    are copied from the corresponding flavor cache
+    folder of other versions of the database
+    or are downloaded from the backend.
+
+    """
+    missing_tables = _missing_tables(
+        db_root,
+        tables,
+        verbose,
+    )
+    if missing_tables:
+        if cached_versions is None:
+            cached_versions = _cached_versions(
+                db.name,
+                version,
+                flavor,
+                cache_root,
+            )
+        if cached_versions:
+            missing_tables = _get_tables_from_cache(
+                missing_tables,
+                db_root,
+                db_root_tmp,
+                deps,
+                cached_versions,
+                num_workers,
+                verbose,
+            )
+        if missing_tables:
+            if backend is None:
+                backend = lookup_backend(db.name, version)
+            _get_tables_from_backend(
+                db,
+                missing_tables,
+                db_root,
+                db_root_tmp,
+                deps,
+                backend,
+                num_workers,
+                verbose,
+            )
 
 
 def _media(
@@ -579,6 +625,70 @@ def _tables(
     return tables
 
 
+def database_cache_folder(
+        name: str,
+        version: str,
+        cache_root: str = None,
+        flavor: Flavor = None,
+) -> str:
+    r"""Create and return database cache folder.
+
+    Args:
+        name: name of database
+        version: version of database
+        cache_root: path to cache folder
+        flavor: flavor of database
+
+    Returns:
+        path to cache folder
+
+    """
+    if cache_root is None:
+        cache_roots = [
+            default_cache_root(True),  # check shared cache first
+            default_cache_root(False),
+        ]
+    else:
+        cache_roots = [cache_root]
+    for cache_root in cache_roots:
+        if flavor is None:
+            db_root = os.path.join(
+                cache_root,
+                name,
+                version,
+            )
+        else:
+            db_root = os.path.join(
+                cache_root,
+                flavor.path(name, version),
+            )
+        db_root = audeer.safe_path(db_root)
+        if os.path.exists(db_root):
+            break
+
+    audeer.mkdir(db_root)
+    return db_root
+
+
+def database_tmp_folder(
+        cache_root: str,
+) -> str:
+    r"""Create and return temporary database cache folder.
+
+    The temporary cache folder is created under ``cache_root + '~'``.
+
+    Args:
+        cache_root: path to cache folder
+
+    Returns:
+        path to temporary cache folder
+
+    """
+    tmp_root = cache_root + '~'
+    tmp_root = audeer.mkdir(tmp_root)
+    return tmp_root
+
+
 def load(
         name: str,
         *,
@@ -653,18 +763,19 @@ def load(
         database object
 
     """
-    if (
-            channels is None
-            and not mixdown
-            and 'mix' in kwargs
-    ):  # pragma: no cover
-        mix = kwargs['mix']
-        channels, mixdown = mix_mapping(mix)
-
     if version is None:
         version = latest_version(name)
-    backend = lookup_backend(name, version)
     deps = dependencies(name, version=version, cache_root=cache_root)
+
+    # backward compatibility to audb<1.0.0
+    channels, mixdown, media = parse_deprecated_load_arguments(
+        channels,
+        mixdown,
+        media,
+        deps,
+        kwargs,
+    )
+
     cached_versions = None
 
     flavor = Flavor(
@@ -674,78 +785,43 @@ def load(
         bit_depth=bit_depth,
         sampling_rate=sampling_rate,
     )
-    db_root, db_root_tmp = _database_root(name, version, flavor, cache_root)
+    db_root = database_cache_folder(name, version, cache_root, flavor)
+    db_root_tmp = database_tmp_folder(db_root)
 
     if verbose:  # pragma: no cover
         print(f'Get:   {name} v{version}')
         print(f'Cache: {db_root}')
 
-    db = _database_header(db_root, db_root_tmp, name, version, flavor, backend)
-    db_is_complete = _database_is_complete(db)
+    # Start with database header without tables
+    db, backend = load_header(
+        db_root,
+        name,
+        version,
+        flavor=flavor,
+        add_audb_meta=True,
+    )
 
-    if 'include' in kwargs or 'exclude' in kwargs:  # pragma: no cover
-        include = None
-        if 'include' in kwargs:
-            include = kwargs['include']
-            warnings.warn(
-                "Argument 'include' is deprecated "
-                "and will be removed with version '1.2.0'. "
-                "Use 'media' instead.",
-                category=UserWarning,
-                stacklevel=2,
-            )
-        exclude = None
-        if 'exclude' in kwargs:  # pragma: no cover
-            exclude = kwargs['exclude']
-            warnings.warn(
-                "Argument 'exclude' is deprecated "
-                "and will be removed with version '1.2.0'. "
-                "Use 'media' instead.",
-                category=UserWarning,
-                stacklevel=2,
-            )
-        if include is not None or exclude is not None:
-            media = _include_exclude_mapping(deps, include, exclude)
+    db_is_complete = _database_is_complete(db)
 
     # filter tables
     requested_tables = _tables(deps, tables)
 
     # load missing tables
     if not db_is_complete:
-        missing_tables = _missing_tables(
-            db_root,
+        _load_tables(
             requested_tables,
+            backend,
+            db_root,
+            db_root_tmp,
+            db,
+            version,
+            cached_versions,
+            deps,
+            flavor,
+            cache_root,
+            num_workers,
             verbose,
         )
-        if missing_tables:
-            if cached_versions is None:
-                cached_versions = _cached_versions(
-                    name,
-                    version,
-                    flavor,
-                    cache_root,
-                )
-            if cached_versions:
-                missing_tables = _get_tables_from_cache(
-                    missing_tables,
-                    db_root,
-                    db_root_tmp,
-                    deps,
-                    cached_versions,
-                    flavor,
-                    num_workers,
-                    verbose,
-                )
-            _get_tables_from_backend(
-                db,
-                missing_tables,
-                db_root,
-                db_root_tmp,
-                deps,
-                backend,
-                num_workers,
-                verbose,
-            )
 
     # filter tables
     if tables is not None:
@@ -760,42 +836,20 @@ def load(
 
     # load missing media
     if not db_is_complete and not only_metadata:
-        missing_media = _missing_media(
-            db_root,
+        _load_media(
             requested_media,
+            backend,
+            db_root,
+            db_root_tmp,
+            name,
+            version,
+            cached_versions,
+            deps,
             flavor,
+            cache_root,
+            num_workers,
             verbose,
         )
-        if missing_media:
-            if cached_versions is None:
-                cached_versions = _cached_versions(
-                    name,
-                    version,
-                    flavor,
-                    cache_root,
-                )
-            if cached_versions:
-                missing_media = _get_media_from_cache(
-                    missing_media,
-                    db_root,
-                    db_root_tmp,
-                    deps,
-                    cached_versions,
-                    flavor,
-                    num_workers,
-                    verbose,
-                )
-            _get_media_from_backend(
-                db,
-                missing_media,
-                db_root,
-                db_root_tmp,
-                flavor,
-                deps,
-                backend,
-                num_workers,
-                verbose,
-            )
 
     # filter media
     if media is not None or tables is not None:
@@ -820,3 +874,290 @@ def load(
         shutil.rmtree(db_root_tmp)
 
     return db
+
+
+def load_header(
+        db_root: str,
+        name: str,
+        version: str,
+        *,
+        flavor: Flavor = None,
+        add_audb_meta: bool = False,
+        overwrite: bool = False,
+) -> typing.Tuple[audformat.Database, typing.Optional[audbackend.Backend]]:
+    r"""Load database header from folder or backend.
+
+    If the database header cannot be found in ``db_root``
+    it will search for the backend that contains the database,
+    load it from there,
+    and store it in ``db_root``.
+
+    Args:
+        db_root: folder of database
+        name: name of database
+        version: version of database
+        flavor: flavor of database,
+            needed if ``add_audb_meta`` is True
+        add_audb_meta: if ``True`` it adds an ``audb`` meta entry
+            to the database header before storing it in cache
+        overwrite: always load header from backend
+            and overwrite the one found in ``db_root``
+
+    Returns:
+        database header and backend
+
+    """
+    backend = None
+    local_header = os.path.join(db_root, define.HEADER_FILE)
+    if overwrite or not os.path.exists(local_header):
+        backend = lookup_backend(name, version)
+        remote_header = backend.join(name, define.HEADER_FILE)
+        if add_audb_meta:
+            db_root_tmp = database_tmp_folder(db_root)
+            local_header = os.path.join(db_root_tmp, define.HEADER_FILE)
+        backend.get_file(remote_header, local_header, version)
+        if add_audb_meta:
+            db = audformat.Database.load(db_root_tmp, load_data=False)
+            db.meta['audb'] = {
+                'root': db_root,
+                'version': version,
+                'flavor': flavor.arguments,
+                'complete': False,
+            }
+            db.save(db_root_tmp, header_only=True)
+            _move_file(db_root_tmp, db_root, define.HEADER_FILE)
+    return audformat.Database.load(db_root, load_data=False), backend
+
+
+def load_media(
+        name: str,
+        media: typing.Union[str, typing.Sequence[str]],
+        *,
+        version: str = None,
+        bit_depth: int = None,
+        channels: typing.Union[int, typing.Sequence[int]] = None,
+        format: str = None,
+        mixdown: bool = False,
+        sampling_rate: int = None,
+        cache_root: str = None,
+        num_workers: typing.Optional[int] = 1,
+        verbose: bool = True,
+) -> typing.List:
+    r"""Load media file(s).
+
+    If you are interested in media files
+    and not the corresponding tables,
+    you can use :func:`audb.load_media`
+    to load them.
+    This will not download any table files
+    to your disk,
+    but share the cache with :func:`audb.load`.
+
+    Args:
+        name: name of database
+        media: load media files provided in the list
+        version: version of database
+        bit_depth: bit depth, one of ``16``, ``24``, ``32``
+        channels: channel selection, see :func:`audresample.remix`.
+            Note that media files with too few channels
+            will be first upsampled by repeating the existing channels.
+            E.g. ``channels=[0, 1]`` upsamples all mono files to stereo,
+            and ``channels=[1]`` returns the second channel
+            of all multi-channel files
+            and all mono files.
+        format: file format, one of ``'flac'``, ``'wav'``
+        mixdown: apply mono mix-down
+        sampling_rate: sampling rate in Hz, one of
+            ``8000``, ``16000``, ``22500``, ``44100``, ``48000``
+        cache_root: cache folder where databases are stored.
+            If not set :meth:`audb.default_cache_root` is used
+        num_workers: number of parallel jobs or 1 for sequential
+            processing. If ``None`` will be set to the number of
+            processors on the machine multiplied by 5
+        verbose: show debug messages
+
+    Returns:
+        paths to media files
+
+    Raises:
+        ValueError: if a media file is requested
+            that is not part of the database
+
+    Example:
+        >>> paths = load_media(
+        ...     'emodb',
+        ...     ['wav/03a01Fa.wav'],
+        ...     version='1.1.1',
+        ...     format='flac',
+        ...     verbose=False,
+        ... )
+        >>> cache_root = audb.default_cache_root()
+        >>> [p[len(cache_root):] for p in paths]
+        ['/emodb/1.1.1/40bb2241/wav/03a01Fa.flac']
+
+    """
+    media = audeer.to_list(media)
+    if len(media) == 0:
+        return []
+
+    if version is None:
+        version = latest_version(name)
+    deps = dependencies(name, version=version, cache_root=cache_root)
+
+    available_files = deps.media
+    for media_file in media:
+        if media_file not in available_files:
+            raise ValueError(
+                f"Could not find '{media_file}' in {name} {version}"
+            )
+
+    cached_versions = None
+
+    flavor = Flavor(
+        channels=channels,
+        format=format,
+        mixdown=mixdown,
+        bit_depth=bit_depth,
+        sampling_rate=sampling_rate,
+    )
+    db_root = database_cache_folder(name, version, cache_root, flavor)
+    db_root_tmp = database_tmp_folder(db_root)
+
+    if verbose:  # pragma: no cover
+        print(f'Get:   {name} v{version}')
+        print(f'Cache: {db_root}')
+
+    # Start with database header without tables
+    db, backend = load_header(
+        db_root,
+        name,
+        version,
+        flavor=flavor,
+        add_audb_meta=True,
+    )
+
+    db_is_complete = _database_is_complete(db)
+
+    # load missing media
+    if not db_is_complete:
+        _load_media(
+            media,
+            backend,
+            db_root,
+            db_root_tmp,
+            name,
+            version,
+            cached_versions,
+            deps,
+            flavor,
+            cache_root,
+            num_workers,
+            verbose,
+        )
+
+    if format is not None:
+        media = [audeer.replace_file_extension(m, format) for m in media]
+
+    return [os.path.join(db_root, m) for m in media]
+
+
+def load_table(
+        name: str,
+        table: str,
+        *,
+        version: str = None,
+        cache_root: str = None,
+        num_workers: typing.Optional[int] = 1,
+        verbose: bool = True,
+) -> pd.DataFrame:
+    r"""Load a database table.
+
+    If you are interested in a single table
+    from a database
+    you can use :func:`audb.load_table`
+    to directly load it.
+    This will not download any media files
+    to your disk,
+    but share the cache with :func:`audb.load`.
+
+    Args:
+        name: name of database
+        table: load table from database
+        cache_root: cache folder where databases are stored.
+            If not set :meth:`audb.default_cache_root` is used
+        num_workers: number of parallel jobs or 1 for sequential
+            processing. If ``None`` will be set to the number of
+            processors on the machine multiplied by 5
+        verbose: show debug messages
+
+    Returns:
+        database table
+
+    Raises:
+        ValueError: if a table is requested
+            that is not part of the database
+
+    Example:
+        >>> df = load_table(
+        ...     'emodb',
+        ...     'emotion',
+        ...     version='1.1.1',
+        ...     verbose=False,
+        ... )
+        >>> df[:3]
+                           emotion  emotion.confidence
+        file
+        wav/03a01Fa.wav  happiness                0.90
+        wav/03a01Nc.wav    neutral                1.00
+        wav/03a01Wa.wav      anger                0.95
+
+    """
+    if version is None:
+        version = latest_version(name)
+    deps = dependencies(name, version=version, cache_root=cache_root)
+
+    if table not in deps.table_ids:
+        raise ValueError(
+            f"Could not find table '{table}' in {name} {version}"
+        )
+
+    cached_versions = None
+
+    db_root = database_cache_folder(name, version, cache_root)
+    db_root_tmp = database_tmp_folder(db_root)
+
+    if verbose:  # pragma: no cover
+        print(f'Get:   {name} v{version}')
+        print(f'Cache: {db_root}')
+
+    # Start with database header without tables
+    db, backend = load_header(
+        db_root,
+        name,
+        version,
+    )
+
+    # Load table
+    table_file = os.path.join(db_root, f'db.{table}')
+    if not (
+            os.path.exists(f'{table_file}.csv')
+            or os.path.exists(f'{table_file}.pkl')
+    ):
+        _load_tables(
+            [table],
+            backend,
+            db_root,
+            db_root_tmp,
+            db,
+            version,
+            cached_versions,
+            deps,
+            Flavor(),
+            cache_root,
+            num_workers,
+            verbose,
+        )
+    table = audformat.Table()
+    table.load(table_file)
+
+    return table._df
