@@ -1,6 +1,7 @@
 import collections
 import os
 import tempfile
+import threading
 import typing
 
 import audbackend
@@ -9,7 +10,6 @@ import audformat
 
 from audb.core import define
 from audb.core.api import dependencies
-from audb.core.config import config
 from audb.core.dependencies import Dependencies
 from audb.core.repository import Repository
 
@@ -19,7 +19,6 @@ def _find_tables(
         db_root: str,
         version: str,
         deps: Dependencies,
-        num_workers: typing.Optional[int],
         verbose: bool,
 ) -> typing.List[str]:
     r"""Update tables."""
@@ -28,29 +27,19 @@ def _find_tables(
 
     db_tables = [f'db.{table}.csv' for table in db.tables]
     for file in set(deps.tables) - set(db_tables):
-        deps.data.pop(file)
+        deps._drop(file)
 
     tables = []
-
-    def job(table: str):
-
+    for table in audeer.progress_bar(
+            db.tables,
+            desc='Find tables',
+            disable=not verbose,
+    ):
         file = f'db.{table}.csv'
         checksum = audbackend.md5(os.path.join(db_root, file))
-        if file not in deps:
-            deps.add_meta(file, table, checksum, version)
+        if file not in deps or checksum != deps.checksum(file):
+            deps._add_meta(file, version, table, checksum)
             tables.append(table)
-        elif checksum != deps.checksum(file):
-            deps.data[file][define.DependField.CHECKSUM] = checksum
-            deps.data[file][define.DependField.VERSION] = version
-            tables.append(table)
-
-    audeer.run_tasks(
-        job,
-        params=[([table], {}) for table in db.tables],
-        num_workers=num_workers,
-        progress_bar=verbose,
-        task_description='Find tables',
-    )
 
     return tables
 
@@ -61,7 +50,6 @@ def _find_media(
         version: str,
         deps: Dependencies,
         archives: typing.Mapping[str, str],
-        num_workers: typing.Optional[int],
         verbose: bool,
 ) -> typing.Set[str]:
 
@@ -71,11 +59,15 @@ def _find_media(
     db_media = db.files
     for file in set(deps.media) - set(db_media):
         media.add(deps.archive(file))
-        deps.data.pop(file)
+        deps._drop(file)
 
     # update version of altered media and insert new ones
 
-    def job(file):
+    for file in audeer.progress_bar(
+            db_media,
+            desc='Find media',
+            disable=not verbose,
+    ):
         path = os.path.join(db_root, file)
         if file not in deps:
             checksum = audbackend.md5(path)
@@ -83,20 +75,12 @@ def _find_media(
                 archive = archives[file]
             else:
                 archive = audeer.uid(from_string=file.replace('\\', '/'))
-            deps.add_media(db_root, file, archive, checksum, version)
-        elif not deps.is_removed(file):
+            deps._add_media(db_root, file, version, archive, checksum)
+        elif not deps.removed(file):
             checksum = audbackend.md5(path)
             if checksum != deps.checksum(file):
-                archive = deps.data[file][define.DependField.ARCHIVE]
-                deps.add_media(db_root, file, archive, checksum, version)
-
-    audeer.run_tasks(
-        job,
-        params=[([file], {}) for file in db_media],
-        num_workers=num_workers,
-        progress_bar=verbose,
-        task_description='Find media',
-    )
+                archive = deps.archive(file)
+                deps._add_media(db_root, file, version, archive, checksum)
 
     return media
 
@@ -115,15 +99,18 @@ def _put_media(
     # select archives with new or altered files for upload
     map_media_to_files = collections.defaultdict(list)
     for file in deps.media:
-        if not deps.is_removed(file):
+        if not deps.removed(file):
             map_media_to_files[deps.archive(file)].append(file)
             if deps.version(file) == version:
                 media.add(deps.archive(file))
 
+    lock = threading.Lock()
+
     def job(archive):
         if archive in map_media_to_files:
             for file in map_media_to_files[archive]:
-                deps.data[file][define.DependField.VERSION] = version
+                with lock:
+                    deps._add_media(db_root, file, version)
             archive_file = backend.join(
                 db_name,
                 define.DEPEND_TYPE_NAMES[define.DependType.MEDIA],
@@ -180,6 +167,7 @@ def publish(
         *,
         archives: typing.Mapping[str, str] = None,
         previous_version: typing.Optional[str] = 'latest',
+        cache_root: str = None,
         num_workers: typing.Optional[int] = 1,
         verbose: bool = True,
 ) -> Dependencies:
@@ -222,6 +210,9 @@ def publish(
             or ``None``
             if no version was published.
             If ``None`` it assumes you start from scratch.
+        cache_root: cache folder where databases are stored.
+            If not set :meth:`audb.default_cache_root` is used.
+            Only used to read the dependencies of the previous version
         num_workers: number of parallel jobs or 1 for sequential
             processing. If ``None`` will be set to the number of
             processors on the machine multiplied by 5
@@ -263,7 +254,8 @@ def publish(
     # load database and dependencies
     deps_path = os.path.join(db_root, define.DEPENDENCIES_FILE)
     deps = Dependencies()
-    deps.load(deps_path)
+    if os.path.exists(deps_path):
+        deps.load(deps_path)
 
     # check if database folder depends on the right version
 
@@ -294,7 +286,11 @@ def publish(
                 tmp_dir,
                 define.DEPENDENCIES_FILE,
             )
-            previous_deps = dependencies(db.name, version=previous_version)
+            previous_deps = dependencies(
+                db.name,
+                version=previous_version,
+                cache_root=cache_root,
+            )
             previous_deps.save(previous_deps_path)
             if audbackend.md5(deps_path) != audbackend.md5(previous_deps_path):
                 raise RuntimeError(
@@ -343,24 +339,14 @@ def publish(
     archives = archives or {}
 
     # publish tables
-    tables = _find_tables(
-        db, db_root, version, deps,
-        num_workers, verbose,
-    )
-    _put_tables(
-        tables, db_root, db.name, version, backend,
-        num_workers, verbose,
-    )
+    tables = _find_tables(db, db_root, version, deps, verbose)
+    _put_tables(tables, db_root, db.name, version, backend, num_workers,
+                verbose)
 
     # publish media
-    media = _find_media(
-        db, db_root, version, deps, archives,
-        num_workers, verbose,
-    )
-    _put_media(
-        media, db_root, db.name, version, deps, backend,
-        num_workers, verbose,
-    )
+    media = _find_media(db, db_root, version, deps, archives, verbose)
+    _put_media(media, db_root, db.name, version, deps, backend, num_workers,
+               verbose)
 
     # publish dependencies and header
     deps.save(deps_path)
