@@ -160,6 +160,22 @@ def fixture_publish_db():
     clear_root(pytest.FILE_SYSTEM_HOST)
 
 
+def test_database_cache_folder():
+    cache_root = os.path.join(pytest.CACHE_ROOT, 'cache')
+    version = '1.0.0'
+    db_root = audb.core.load.database_cache_folder(
+        DB_NAME,
+        version,
+        cache_root,
+    )
+    expected_db_root = os.path.join(
+        cache_root,
+        DB_NAME,
+        version,
+    )
+    assert db_root == expected_db_root
+
+
 @pytest.mark.parametrize(
     'format',
     [
@@ -170,11 +186,11 @@ def fixture_publish_db():
 @pytest.mark.parametrize(
     'version',
     [
+        None,  # 3.0.0
         '1.0.0',
         '1.1.0',
         '1.1.1',
         '2.0.0',
-        None,  # 3.0.0
         pytest.param(
             '4.0.0',
             marks=pytest.mark.xfail(raises=RuntimeError),
@@ -244,6 +260,122 @@ def test_load(format, version):
         assert os.path.exists(os.path.join(db_root, f'db.{table}.csv'))
 
 
+@pytest.mark.parametrize(
+    'version, media, format',
+    [
+        (
+            '1.0.0',
+            [],
+            None,
+        ),
+        (
+            '1.0.0',
+            'audio/001.wav',
+            'wav',
+        ),
+        pytest.param(
+            '1.0.0',
+            ['audio/001.flac', 'audio/002.flac'],
+            'flac',
+            marks=pytest.mark.xfail(raises=ValueError),
+        ),
+        (
+            '1.0.0',
+            ['audio/001.wav', 'audio/002.wav'],
+            'flac',
+        ),
+        (
+            None,
+            ['audio/001.wav'],
+            None,
+        ),
+    ]
+)
+def test_load_media(version, media, format):
+
+    paths = audb.load_media(
+        DB_NAME,
+        media,
+        version=version,
+        format=format,
+        verbose=False,
+    )
+    expected_paths = [
+        os.path.join(pytest.CACHE_ROOT, p)
+        for p in paths
+    ]
+    if format is not None:
+        expected_paths = [
+            audeer.replace_file_extension(p, format)
+            for p in expected_paths
+        ]
+    assert paths == expected_paths
+
+    # Clear cache to force loading from other cache
+    if version is None:
+        version = audb.latest_version(DB_NAME)
+    cache_root = audb.core.load.database_cache_folder(
+        DB_NAME,
+        version,
+        pytest.CACHE_ROOT,
+        audb.Flavor(format=format),
+    )
+    shutil.rmtree(cache_root)
+    paths2 = audb.load_media(
+        DB_NAME,
+        media,
+        version=version,
+        format=format,
+        verbose=False,
+    )
+    assert paths2 == paths
+
+
+@pytest.mark.parametrize(
+    'version, table',
+    [
+        (
+            '1.0.0',
+            'emotion',
+        ),
+        pytest.param(
+            '1.0.0',
+            'non-existing-table',
+            marks=pytest.mark.xfail(raises=ValueError),
+        ),
+        (
+            None,
+            'emotion',
+        ),
+    ]
+)
+def test_load_table(version, table):
+
+    df = audb.load_table(
+        DB_NAME,
+        table,
+        version=version,
+        verbose=False,
+    )
+    if version is None:
+        expected_files = [
+            'audio/001.wav',
+            'audio/002.wav',
+            'audio/003.wav',
+            'audio/004.wav',
+        ]
+    elif version == '1.0.0':
+        expected_files = [
+            'audio/001.wav',
+            'audio/002.wav',
+            'audio/003.wav',
+            'audio/004.wav',
+            'audio/005.wav',
+        ]
+    files = sorted(list(set(df.index.get_level_values('file'))))
+    assert files == expected_files
+
+
 @pytest.mark.parametrize(
     'version',
     [
